summaryrefslogtreecommitdiffstats
path: root/lib/util/kscriptactionmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/kscriptactionmanager.h')
-rw-r--r--lib/util/kscriptactionmanager.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/lib/util/kscriptactionmanager.h b/lib/util/kscriptactionmanager.h
index 78833d2b..47d1a04e 100644
--- a/lib/util/kscriptactionmanager.h
+++ b/lib/util/kscriptactionmanager.h
@@ -21,8 +21,8 @@
#define KScriptAction_H
#include <scriptclientinterface.h>
-#include <qobject.h>
-#include <qptrlist.h>
+#include <tqobject.h>
+#include <tqptrlist.h>
class KAction;
class KActionCollection;
@@ -35,11 +35,11 @@ class QTimer;
*
* @author ian geiser geiseri@sourcextreme.com
*/
-class KScriptAction : public QObject, public KScriptClientInterface {
+class KScriptAction : public TQObject, public KScriptClientInterface {
Q_OBJECT
public:
- KScriptAction( const QString &scriptDesktopFile, QObject *interface, KActionCollection *ac );
+ KScriptAction( const TQString &scriptDesktopFile, TQObject *interface, KActionCollection *ac );
virtual ~KScriptAction();
@@ -55,18 +55,18 @@ public:
signals:
// Reimplemented from KScript
- void error ( const QString &msg );
- void warning ( const QString &msg );
- void output ( const QString &msg );
+ void error ( const TQString &msg );
+ void warning ( const TQString &msg );
+ void output ( const TQString &msg );
void progress ( int percent );
- void done ( KScriptClientInterface::Result result, const QVariant &returned );
+ void done ( KScriptClientInterface::Result result, const TQVariant &returned );
signals:
- void scriptError ( const QString &msg );
- void scriptWarning ( const QString &msg );
- void scriptOutput ( const QString &msg );
+ void scriptError ( const TQString &msg );
+ void scriptWarning ( const TQString &msg );
+ void scriptOutput ( const TQString &msg );
void scriptProgress ( int percent );
- void scriptDone ( KScriptClientInterface::Result result, const QVariant &returned );
+ void scriptDone ( KScriptClientInterface::Result result, const TQVariant &returned );
private slots:
void activate();
@@ -75,13 +75,13 @@ private slots:
private:
KAction *m_action;
- QString m_scriptName;
- QString m_scriptType;
- QString m_scriptFile;
- QString m_scriptMethod;
+ TQString m_scriptName;
+ TQString m_scriptType;
+ TQString m_scriptFile;
+ TQString m_scriptMethod;
KScriptInterface *m_interface;
bool m_isValid;
- QTimer *m_timeout;
+ TQTimer *m_timeout;
uint m_refs;
};
@@ -90,39 +90,39 @@ private:
* Scripts are not actually loaded until they are actually executed.
* @author ian geiser <geiseri@sourcextreme.com>
*/
-class KScriptActionManager : public QObject {
+class KScriptActionManager : public TQObject {
Q_OBJECT
public:
/**
* Create a script manager that is attached to an action collection.
*/
- KScriptActionManager( QObject *parent, KActionCollection *ac );
+ KScriptActionManager( TQObject *parent, KActionCollection *ac );
~KScriptActionManager();
/**
* Return all currently loaded scripts in a direcotry and attaches them
* to a QObject interface. If the dirs are empty the current applications
* scripts directory is used. The dirs are actual directories to search
* in the $KDEPATH/data/ direcories. So if you add "coolapp/data" then
* the manager will search in $KDEPATH/data/coolapp/data for all desktop
* files that are scripts.
*/
- QPtrList<KAction> scripts( QObject *interface, const QStringList &dirs = QStringList() ) const;
+ TQPtrList<KAction> scripts( TQObject *interface, const TQStringList &dirs = TQStringList() ) const;
signals:
/**
* Returns an error message from a script.
*/
- void scriptError ( const QString &msg );
+ void scriptError ( const TQString &msg );
/**
* Returns a warning message from a script.
*/
- void scriptWarning ( const QString &msg );
+ void scriptWarning ( const TQString &msg );
/**
* Returns a standard out message from a script.
*/
- void scriptOutput ( const QString &msg );
+ void scriptOutput ( const TQString &msg );
/**
* Returns the percentage complete of an operation in the script.
*/
@@ -130,10 +130,10 @@ signals:
/**
* Notifies that the script has finished.
*/
- void scriptDone( KScriptClientInterface::Result result, const QVariant &returned );
+ void scriptDone( KScriptClientInterface::Result result, const TQVariant &returned );
private:
- mutable QPtrList<KScriptAction> m_actions;
+ mutable TQPtrList<KScriptAction> m_actions;
KActionCollection *m_ac;
};
#endif
@@ -90,39 +90,39 @@ private:
/**
* Return all currently loaded scripts in a direcotry and attaches them
- * to a QObject interface. If the dirs are empty the current applications
+ * to a TQObject interface. If the dirs are empty the current applications
* scripts directory is used. The dirs are actual directories to search
* in the $KDEPATH/data/ direcories. So if you add "coolapp/data" then